@@ -53,7 +53,8 @@ from specmate_datasets import specmate_refDataset
 from specmate_datasets import specmate_peakDataset
 from specmate_datasets import specmate_functionDataset
 #from specmate_menubar import specmate_menubar
-from specmate_globals import *
+#from specmate_globals import *
+from specmate_globals import appName,DEFAULT_REF_COEFF,DEFAULT_NAMES,DEFAULT_LABELS,labelStr
 #from min5 import ga_minimize
 #----------------------------------------------------------------------------
 #----------------------------------------------------------------------------
@@ -91,6 +92,9 @@ class specmate_backend_basicDataAndIO():
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
 	def interpolateAll(self):
+		"""
+		Interpolate all spectra, peaks, and functions to the X-Axis of the current spectrum
+		"""
 		if len(self.refSpectra)>0:
 			for eachSpectrum in self.refSpectra:
 				eachSpectrum.interpolate(self.specData.data[:,0])
@@ -129,7 +133,9 @@ class specmate_backend_basicDataAndIO():
 	#--------------------------------------------------------------------------------
 	def shiftSpectrum(self,shift):
 		"""
-		...
+		shift X-axis of the spectrum
+		@param shift: shift x-axis by this value
+		@type shift: float
 		@return: success(0)/fail(1)
 		@rtype: int
 		"""
@@ -145,7 +151,7 @@ class specmate_backend_basicDataAndIO():
 	#--------------------------------------------------------------------------------
 	def clearBackground(self):
 		"""
-		Clear Background data.
+		Clear background data.
 		"""
 		self.background.clear()
 		self._calcDiff()
@@ -204,8 +210,11 @@ class specmate_backend_basicDataAndIO():
 		
 		@param filename: file to open
 		@type filename: string
+		@param calc: whether or not to call self._calcDiff() in the end.
+		@param calc: boolean
 		@return: success(0)/fail(1)
 		@rtype: int
+		@default calc: True
 		"""
 		try:
 			self.refSpectra.append(specmate_refDataset(filename,DEFAULT_REF_COEFF))
@@ -230,6 +239,8 @@ class specmate_backend_basicDataAndIO():
 		Open a number of txt-based reference-spectra files and append the datasets to self.refSpectra. Create interpolated data if possible. Set coeff,maxCoeff based on the dataset and self.specData  
 		@param filenames: files to open
 		@type filenames: list of string
+		@return: number of files that couldn't be opened
+		@rtype: int
 		"""
 		nNotOpened=0
 		for filename in filenames:
@@ -296,7 +307,7 @@ class specmate_backend_basicDataAndIO():
 		if len(self.refSpectra)!=len(names):
 			return(1)
 		for i in xrange(0,len(self.refSpectra)):
-			self.refSpectra[i].name=names[i][1]
+			self.refSpectra[i].name=names[i]
 		self._createPlotData()
 		return(0)
 	#--------------------------------------------------------------------------------
@@ -529,7 +540,7 @@ class specmate_backend_basicDataAndIO():
 
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
-	def _calcDiff(self):
+	def _calcDiff(self,autoscale=False):
 		"""
 		Calculate the residual spectrum from all other datasets, store it in self.diffData. Call self._createPlotData() in the end.
 		"""
@@ -554,13 +565,13 @@ class specmate_backend_basicDataAndIO():
 			#	self.diffData.data[:,:]=self.specData.data[:,:]
 			self.diffData.data[:,1]-=self.background.Y()[:]	
 			self.diffData.hasData=True
-		self._createPlotData()
+		self._createPlotData(autoscale)
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
 
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
-	def _createPlotData(self):
+	def _createPlotData(self,autoscale=False):
 		"""
 		Create a dataset that contains the all data for the plot and (if self.frontend!="None") tell the frontend to plot it (via self.frontend.replot()).
 		"""
@@ -581,7 +592,7 @@ class specmate_backend_basicDataAndIO():
 		if self.diffData.hasData:
 			self.plotData.append([self.diffData.X()[:],self.diffData.data[:,1], self.diffData.name,1.0,'k-'])
 		if self.frontend!="None":
-			self.frontend.replot()
+			self.frontend.replot(autoscale)
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
 
@@ -691,7 +702,7 @@ class specmate_backend_projectIO(specmate_backend_basicDataAndIO):
 				name='functionSpectrum%d' % (i)
 				self.functionSpectra.append(specmate_functionDataset())
 				self.functionSpectra[i].importDataFromDict(data[name])
-		self._calcDiff()
+		self._calcDiff(autoscale=True)
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
 
@@ -713,7 +724,6 @@ class specmate_backend_projectIO(specmate_backend_basicDataAndIO):
 			return(0)
 		except:
 			warnings.warn("Couldn't write file: "+filename,UserWarning)
-			#print "Couldn't write file: "+filename
 			return(1)
 	#--------------------------------------------------------------------------------
 	#--------------------------------------------------------------------------------
@@ -807,7 +817,12 @@ class specmate_backend_projectIO(specmate_backend_basicDataAndIO):
 	def saveSingleSet(self,filename,which='spectrum',number=-1,name='None',which_data='interpolated'):
 		"""
 		Save a single dataset as "txt" 
-		
+		@param which: which dataset type is to be saved
+		@type which: string ("spectrum","background","reference","peak","function")
+		@param number: index of reference or peak or function
+		@type number: int
+		@param name: name of reference or peak or function
+		@type name: string
 		@param filename: filename to write
 		@type filename: string
 		@return: success(0)/fail(1)
@@ -819,7 +834,6 @@ class specmate_backend_projectIO(specmate_backend_basicDataAndIO):
 				dataset.write(filename,which_data)
 			except:
 				warnings.warn("Couldn't write file: "+filename,UserWarning)
-				#print "Couldn't write file: "+filename
 				return(1)
 			return(0)
 		else:
@@ -879,7 +893,6 @@ class specmate_backend_projectIO(specmate_backend_basicDataAndIO):
 			na.savetxt(filename,na.transpose(na.array(save_data)),fmt='%.5e')#,header=saveHeader)
 		except:
 			warnings.warn("Warning: Couldn't write file "+filename,UserWarning)
-			#print "Warning: Couldn't write file "+filename
 			return(1)
 		infoFilename=filename.split('.')[0]+'_info.txt'
 		infoFile=open(infoFilename,'w')
@@ -894,8 +907,8 @@ class specmate_backend_projectIO(specmate_backend_basicDataAndIO):
 	#--------------------------------------------------------------------------------
 	def __init__(self,argv=['None']):
 		"""
-		Constructor: ... 
-		@param argv: list of filenames to open: first entry is used as spectrum, all following names as reference spectra.
+		Constructor: Will try to open argv[1] as project if possible or as spectrum otherwise. If argv[2 ...] exist, these will be used as additional references. 
+		@param argv: list of filenames to open. 
 		@type argv: list of strings
 		"""
 		self.frontend="None"
