@@ -39,7 +39,7 @@ except:
 	print "Please install scipy!"
 	sys.exit(1)
 
-from specmate_globals import *
+#from specmate_globals import *
 #----------------------------------------------------------------------------
 #----------------------------------------------------------------------------
 
