@@ -35,11 +35,12 @@ except:
 	print "Please install wxPython!"
 	sys.exit(1)
 
-try:
-	import wxmpl
-except:
-	print "It seems that you don't have wxmpl installed, I'll try to use a copy distributed along with SpecMate."
-	import copy_of_wxmpl as wxmpl
+#try:
+#	import wxmpl
+#except:
+#	print "It seems that you don't have wxmpl installed, I'll try to use a copy distributed along with SpecMate."
+import copy_of_wxmpl as wxmpl
+
 try:
 	import numpy as na
 except:
@@ -55,8 +56,11 @@ except:
 from specmate_datasets import specmate_singleDataset
 from specmate_menubar import specmate_menubar
 from specmate_backend import specmate_backend
-from specmate_globals import *
-from specmate_frontend_popups import specmate_editNamesWindow, specmate_refWindow,specmate_comboboxWindow 
+#from specmate_globals import *
+from specmate_globals import appName
+#from specmate_frontend_popups import specmate_editNamesWindow, specmate_refWindow,specmate_comboboxWindow 
+from specmate_frontend_popups import specmate_editNamesWindow,specmate_comboboxWindow 
+from specmate_refWindow import specmate_refWindow 
 #from specmate_addPeakWindow import specmate_addPeakWindow
 from specmate_addPeakWindow import specmate_modPeakWindow
 from specmate_fitWindow import specmate_fitWindow
@@ -83,110 +87,197 @@ class CustomToolbar(NavigationToolbar2Wx):
 		@param canvas: matplotlib plotting canvas object.
 		@param parent: instance of a class that has at least an instance named "onButtonHome(self,event)".
 		"""
+	    	self.toolitems = (
+        			('Home', 'Reset original view', 'home', 'home'),
+        			#('Back', 'Back to  previous view', 'back', 'back'),
+        			#('Forward', 'Forward to next view', 'forward', 'forward'),
+        			#(None, None, None, None),
+        			('Pan', 'Pan axes with left mouse, zoom with right', 'move', 'pan'),
+        			('Zoom', 'Zoom to rectangle', 'zoom_to_rect', 'zoom'),
+        			#(None, None, None, None),
+        			#('Subplots', 'Configure subplots', 'subplots', 'configure_subplots'),
+        			('Save', 'Save the figure', 'filesave', 'save_figure'),
+      				)
 		NavigationToolbar2Wx.__init__(self,canvas)
 		self.parent=parent
-	#--------------------------------------------------------------------------------
-	#--------------------------------------------------------------------------------
-	
-	def _load_bitmap(self,filename):
-    		"""
-		This function is copied(and modified) from matplotlib's backend_wx.py.
+	###--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
 
-    		Load a bitmap file from the backends/images subdirectory in which the
-    		matplotlib library is installed. The filename parameter should not
-    		contain any path information as this is determined automatically.
-
-    		Returns a wx.Bitmap object
-    		"""
-
-    		basedir = os.path.join(rcParams['datapath'],'images')
-
-    		bmpFilename = os.path.normpath(os.path.join(basedir, filename))
-    		if not os.path.exists(bmpFilename):
-        		raise IOError('Could not find bitmap file "%s"; dying'%bmpFilename)
-
-    		bmp = wx.Bitmap(bmpFilename)
-    		return bmp
-
-	def _init_toolbar(self):
-    		"""
-		This function is copied(and modified) from matplotlib's backend_wx.py.
-
-    		"""
-		#DEBUG_MSG("_init_toolbar", 1, self)
-		self._parent = self.canvas.GetParent()
-		_NTB2_HOME	=wx.NewId()
-		self._NTB2_BACK	=wx.NewId()
-		self._NTB2_FORWARD =wx.NewId()
-		self._NTB2_PAN	 =wx.NewId()
-		#self._NTB2_ZOOM	=wx.NewId()
-		_NTB2_SAVE	= wx.NewId()
-		#_NTB2_SUBPLOT	=wx.NewId()
-
-		self.SetToolBitmapSize(wx.Size(24,24))
-
-		self.AddSimpleTool(_NTB2_HOME, self._load_bitmap('home.png'),
-						   'Reset Original View', 'Reset original view')
-		self.AddSimpleTool(self._NTB2_BACK, self._load_bitmap('back.png'),
-						   'Back', 'Back navigation view')
-		self.AddSimpleTool(self._NTB2_FORWARD, self._load_bitmap('forward.png'),
-						   'Forward', 'Forward navigation view')
-		# todo: get new bitmap
-		self.AddCheckTool(self._NTB2_PAN, self._load_bitmap('move.png'),
-						   shortHelp='Pan',
-						   longHelp='Pan with left, zoom with right')
-		#self.AddCheckTool(self._NTB2_ZOOM, self._load_bitmap('zoom_to_rect.png'),
-		#				   shortHelp='Zoom', longHelp='Zoom to rectangle')
-
-		self.AddSeparator()
-		#self.AddSimpleTool(_NTB2_SUBPLOT, self._load_bitmap('subplots.png'),
-		#				   'Configure subplots', 'Configure subplot parameters')
-
-		self.AddSimpleTool(_NTB2_SAVE, self._load_bitmap('filesave.png'),
-						   'Export Image to File', 'Save plot contents to file')
-
-		self.Bind( wx.EVT_TOOL, self.home, id=_NTB2_HOME)
-		self.Bind( wx.EVT_TOOL, self.forward, id=self._NTB2_FORWARD)
-		self.Bind( wx.EVT_TOOL, self.back, id=self._NTB2_BACK)
-		#self.Bind( wx.EVT_TOOL, self.zoom, id=self._NTB2_ZOOM)
-		self.Bind( wx.EVT_TOOL, self.pan, id=self._NTB2_PAN)
-		#self.Bind( wx.EVT_TOOL, self.configure_subplot, id=_NTB2_SUBPLOT)
-		self.Bind( wx.EVT_TOOL, self.save, id=_NTB2_SAVE)
-
-		self.Realize()
-
-	
-	#--------------------------------------------------------------------------------
-	#--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
+	def set_history_buttons(self):
+        	"""
+		Enable or disable back/forward button
+		"""
+        	pass
+	###--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
 	def home(self,event):
 		"""
 		reimplement event handler "NavigationToolbar2Wx.home()" to call parent.onButtonHome(event) when the "home"-Button is pressed.
 		"""
 		self.parent.onButtonHome(event)
-	#--------------------------------------------------------------------------------
-	#--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
 
-	#--------------------------------------------------------------------------------
-	#--------------------------------------------------------------------------------
-	def pan(self,event):
-		"""
-		reimplement event handler "NavigationToolbar2Wx.pan()" to call parent.onButtonHome(event) when the "pan"-Button is pressed.
-		"""
-		self.parent.onButtonHome(event)
-	#--------------------------------------------------------------------------------
-	#--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
+	#def pan(self,event):
+	#	"""
+	#	reimplement event handler "NavigationToolbar2Wx.pan()" to call parent.onButtonHome(event) when the "pan"-Button is pressed.
+	#	"""
+	#	self.parent.onButtonHome(event)
+	###--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
 
-	#--------------------------------------------------------------------------------
-	#--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
 	def configure_subplot(self,event):
 		"""
 		reimplement event handler "NavigationToolbar2Wx.configure_subplot()" to do nothing when the "configure subplot"-Button is pressed.
 		"""
 		print "function: 'configure subplot' not implemented!"
-	#--------------------------------------------------------------------------------
-	#--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
+	##--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
+	#def zoom(self,event):
+	#	"""
+	#	reimplement event handler "NavigationToolbar2Wx.configure_subplot()" to do nothing when the "configure subplot"-Button is pressed.
+	#	"""
+	#	print "function: 'zoom' not implemented!"
+	###--------------------------------------------------------------------------------
+	###--------------------------------------------------------------------------------
 #-----------------------------------------------------------------------------------------
 #-----------------------------------------------------------------------------------------
+##-----------------------------------------------------------------------------------------
+## begin customized matplotlib-toolbar
+##-----------------------------------------------------------------------------------------
+#class CustomToolbar(NavigationToolbar2Wx):
+#	"""
+#	Customized toolbar for the PlotPanel. 
+#	@ivar parent: parent instance, should have event handler ".onButtonHome(event)" implemented.
+#	@type parent: python class
+#	"""
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+#	def __init__(self,canvas,parent):
+#		"""
+#		@param canvas: matplotlib plotting canvas object.
+#		@param parent: instance of a class that has at least an instance named "onButtonHome(self,event)".
+#		"""
+#		NavigationToolbar2Wx.__init__(self,canvas)
+#		self.parent=parent
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+#	
+#	def _load_bitmap(self,filename):
+#    		"""
+#		This function is copied(and modified) from matplotlib's backend_wx.py.
+#
+#    		Load a bitmap file from the backends/images subdirectory in which the
+#    		matplotlib library is installed. The filename parameter should not
+#    		contain any path information as this is determined automatically.
+#
+#    		Returns a wx.Bitmap object
+#    		"""
+#
+#    		basedir = os.path.join(rcParams['datapath'],'images')
+#
+#    		bmpFilename = os.path.normpath(os.path.join(basedir, filename))
+#    		if not os.path.exists(bmpFilename):
+#        		raise IOError('Could not find bitmap file "%s"; dying'%bmpFilename)
+#
+#    		bmp = wx.Bitmap(bmpFilename)
+#    		return bmp
+#
+#	def save2(self, *args):
+#		try:
+#			self.save_figure(*args)
+#		except:
+#			self.save(*args)
+#
+#	def _init_toolbar(self):
+#    		"""
+#		This function is copied(and modified) from matplotlib's backend_wx.py.
+#
+#    		"""
+#		#DEBUG_MSG("_init_toolbar", 1, self)
+#		self._parent = self.canvas.GetParent()
+#		_NTB2_HOME	=wx.NewId()
+#		self._NTB2_BACK	=wx.NewId()
+#		self._NTB2_FORWARD =wx.NewId()
+#		self._NTB2_PAN	 =wx.NewId()
+#		#self._NTB2_ZOOM	=wx.NewId()
+#		_NTB2_SAVE	= wx.NewId()
+#		#_NTB2_SUBPLOT	=wx.NewId()
+#
+#		self.SetToolBitmapSize(wx.Size(24,24))
+#
+#		self.AddSimpleTool(_NTB2_HOME, self._load_bitmap('home.png'),
+#						   'Reset Original View', 'Reset original view')
+#		self.AddSimpleTool(self._NTB2_BACK, self._load_bitmap('back.png'),
+#						   'Back', 'Back navigation view')
+#		self.AddSimpleTool(self._NTB2_FORWARD, self._load_bitmap('forward.png'),
+#						   'Forward', 'Forward navigation view')
+#		# todo: get new bitmap
+#		self.AddCheckTool(self._NTB2_PAN, self._load_bitmap('move.png'),
+#						   shortHelp='Pan',
+#						   longHelp='Pan with left, zoom with right')
+#		#self.AddCheckTool(self._NTB2_ZOOM, self._load_bitmap('zoom_to_rect.png'),
+#		#				   shortHelp='Zoom', longHelp='Zoom to rectangle')
+#
+#		self.AddSeparator()
+#		#self.AddSimpleTool(_NTB2_SUBPLOT, self._load_bitmap('subplots.png'),
+#		#				   'Configure subplots', 'Configure subplot parameters')
+#
+#		self.AddSimpleTool(_NTB2_SAVE, self._load_bitmap('filesave.png'),
+#						   'Export Image to File', 'Save plot contents to file')
+#
+#		self.Bind( wx.EVT_TOOL, self.home, id=_NTB2_HOME)
+#		self.Bind( wx.EVT_TOOL, self.forward, id=self._NTB2_FORWARD)
+#		self.Bind( wx.EVT_TOOL, self.back, id=self._NTB2_BACK)
+#		#self.Bind( wx.EVT_TOOL, self.zoom, id=self._NTB2_ZOOM)
+#		self.Bind( wx.EVT_TOOL, self.pan, id=self._NTB2_PAN)
+#		#self.Bind( wx.EVT_TOOL, self.configure_subplot, id=_NTB2_SUBPLOT)
+#		self.Bind( wx.EVT_TOOL, self.save2, id=_NTB2_SAVE)
+#
+#		self.Realize()
+#
+#	
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+#	def home(self,event):
+#		"""
+#		reimplement event handler "NavigationToolbar2Wx.home()" to call parent.onButtonHome(event) when the "home"-Button is pressed.
+#		"""
+#		self.parent.onButtonHome(event)
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+#
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+#	def pan(self,event):
+#		"""
+#		reimplement event handler "NavigationToolbar2Wx.pan()" to call parent.onButtonHome(event) when the "pan"-Button is pressed.
+#		"""
+#		self.parent.onButtonHome(event)
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+#
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+#	def configure_subplot(self,event):
+#		"""
+#		reimplement event handler "NavigationToolbar2Wx.configure_subplot()" to do nothing when the "configure subplot"-Button is pressed.
+#		"""
+#		print "function: 'configure subplot' not implemented!"
+#	#--------------------------------------------------------------------------------
+#	#--------------------------------------------------------------------------------
+##-----------------------------------------------------------------------------------------
+##-----------------------------------------------------------------------------------------
 
 ##-----------------------------------------------------------------------------------------
 ##-----------------------------------------------------------------------------------------
@@ -454,12 +545,15 @@ class MainWindow_windowContents(MainWindow_helperFunctions):
 		axes.set_ylabel(self.backend.namesAndLabels['Axis Label (Y)'])
 		if self.backend.namesAndLabels['Graph Title']!="None":
 			axes.set_title(self.backend.namesAndLabels['Graph Title'])
-		axes.legend(loc="best")
+		if len(self.backend.plotData)>0 or self.backend.background.hasData:
+			axes.legend(loc="best")
 		axes.grid()
 		
 		# restore the zoom limits (unless they're for an empty plot)
 		if autoscale:
 			axes.autoscale()
+			if self.backend.specData.hasData:
+				axes.set_xlim(na.min(self.backend.specData.X()),na.max(self.backend.specData.X()))
 			#axes.set_xlim(self.backend.xMin,self.backend.xMax)
 		elif xlim != (0.0, 1.0) or ylim != (0.0, 1.0):
 			axes.set_xlim(xlim)
